import request from "@/utils/request";
import { MenuQuery, MenuVO, MenuForm, RouteVO } from "./model";

class MenuAPI {
  /**
   * 获取路由列表
   */
  static getRoutes() {
    return new Promise((resolve) => {
      resolve([
        {
          path: "/split",
          component: "Layout",
          redirect: "/split/split1",
          name: "/split",
          meta: {
            title: "算法分割",
            icon: "split",
            hidden: false,
            roles: ["GUEST", "ADMIN", "ADMIN6"],
            alwaysShow: false,
          },
          children: [
            {
              path: "split1",
              component: "split/split1/index",
              name: "split1",
              meta: {
                title: "算法分割1",
                icon: "user",
                hidden: false,
                roles: ["ADMIN", "GUEST"],
                keepAlive: true,
                alwaysShow: false,
              },
            },
            {
              path: "/split2",
              component: "split/split1/index",
              name: "/split2",
              meta: {
                title: "算法分割2",
                icon: "role",
                hidden: false,
                roles: ["ADMIN6", "GUEST", "ADMIN"],
                keepAlive: true,
                alwaysShow: false,
              },
            },
          ],
        },
        {
          path: "/internetProtocol",
          component: "Layout",
          redirect: "/internetProtocol/index",
          name: "/internetProtocol",
          meta: {
            title: "互联协议",
            icon: "web",
            hidden: false,
            roles: ["GUEST", "ADMIN", "ADMIN6"],
            alwaysShow: false,
          },
          children: [
            {
              path: "user",
              component: "system/user/index",
              name: "User",
              meta: {
                title: "互联协议1",
                icon: "user",
                hidden: false,
                roles: ["ADMIN", "GUEST"],
                keepAlive: true,
                alwaysShow: false,
              },
            },
            {
              path: "role",
              component: "system/role/index",
              name: "Role",
              meta: {
                title: "互联协议2",
                icon: "role",
                hidden: false,
                roles: ["ADMIN6", "GUEST", "ADMIN"],
                keepAlive: true,
                alwaysShow: false,
              },
            },
          ],
        },
        {
          path: "/simulationEvaluation",
          component: "Layout",
          redirect: "/simulationEvaluation/index",
          name: "/simulationEvaluation",
          meta: {
            title: "仿真评估",
            icon: "simu",
            hidden: false,
            roles: ["GUEST", "ADMIN", "ADMIN6"],
            alwaysShow: false,
          },
          children: [
            {
              path: "user",
              component: "system/user/index",
              name: "User",
              meta: {
                title: "仿真评估1",
                icon: "user",
                hidden: false,
                roles: ["ADMIN", "GUEST"],
                keepAlive: true,
                alwaysShow: false,
              },
            },
            {
              path: "role",
              component: "system/role/index",
              name: "Role",
              meta: {
                title: "仿真评估2",
                icon: "role",
                hidden: false,
                roles: ["ADMIN6", "GUEST", "ADMIN"],
                keepAlive: true,
                alwaysShow: false,
              },
            },
          ],
        },
        {
          path: "/operatorLibrary",
          component: "Layout",
          redirect: "/operatorLibrary/index",
          name: "/operatorLibrary",
          meta: {
            title: "算子库管理",
            icon: "oper",
            hidden: false,
            roles: ["GUEST", "ADMIN", "ADMIN6"],
            alwaysShow: false,
          },
          children: [
            {
              path: "operatorLibrary",
              component: "/operatorLibrary/index",
              name: "operatorLibrary",
              meta: {
                title: "算子库管理1",
                icon: "user",
                hidden: false,
                roles: ["ADMIN", "GUEST"],
                keepAlive: true,
                alwaysShow: false,
              },
            },
            {
              path: "operatorLibrary2",
              component: "/operatorLibrary/index2",
              name: "operatorLibrary2",
              meta: {
                title: "算子库管理2",
                icon: "role",
                hidden: false,
                roles: ["ADMIN6", "GUEST", "ADMIN"],
                keepAlive: true,
                alwaysShow: false,
              },
            },
          ],
        },
        {
          path: "/dataMgr",
          component: "Layout",
          redirect: "/dataMgr/user",
          name: "/dataMgr",
          meta: {
            title: "数据管理",
            icon: "db",
            hidden: false,
            roles: ["GUEST", "ADMIN", "ADMIN6"],
            alwaysShow: false,
          },
          children: [
            {
              path: "user",
              component: "system/user/index",
              name: "User",
              meta: {
                title: "数据管理1",
                icon: "user",
                hidden: false,
                roles: ["ADMIN", "GUEST"],
                keepAlive: true,
                alwaysShow: false,
              },
            },
            {
              path: "role",
              component: "system/role/index",
              name: "Role",
              meta: {
                title: "数据管理2",
                icon: "role",
                hidden: false,
                roles: ["ADMIN6", "GUEST", "ADMIN"],
                keepAlive: true,
                alwaysShow: false,
              },
            },
          ],
        },
        {
          path: "/tester",
          component: "Layout",
          redirect: "/tester/index",
          name: "/tester",
          meta: {
            title: "算法测试仪管理",
            icon: "test",
            hidden: false,
            roles: ["GUEST", "ADMIN", "ADMIN6"],
            alwaysShow: false,
          },
          children: [
            {
              path: "user",
              component: "system/user/index",
              name: "User",
              meta: {
                title: "算法测试仪管理1",
                icon: "user",
                hidden: false,
                roles: ["ADMIN", "GUEST"],
                keepAlive: true,
                alwaysShow: false,
              },
            },
            {
              path: "role",
              component: "system/role/index",
              name: "Role",
              meta: {
                title: "算法算法测试仪管理2",
                icon: "role",
                hidden: false,
                roles: ["ADMIN6", "GUEST", "ADMIN"],
                keepAlive: true,
                alwaysShow: false,
              },
            },
          ],
        },
        {
          path: "/system",
          component: "Layout",
          redirect: "/system/index",
          name: "/system",
          meta: {
            title: "系统管理",
            icon: "system",
            hidden: false,
            roles: ["GUEST", "ADMIN", "ADMIN6"],
            alwaysShow: false,
          },
          children: [
            {
              path: "user",
              component: "system/user/index",
              name: "User",
              meta: {
                title: "系统管理1",
                icon: "user",
                hidden: false,
                roles: ["ADMIN", "GUEST"],
                keepAlive: true,
                alwaysShow: false,
              },
            },
            {
              path: "role",
              component: "system/role/index",
              name: "Role",
              meta: {
                title: "系统管理2",
                icon: "role",
                hidden: false,
                roles: ["ADMIN6", "GUEST", "ADMIN"],
                keepAlive: true,
                alwaysShow: false,
              },
            },
          ],
        },
      ]);
    });
    /*
    return request<any, RouteVO[]>({
      url: "/api/v1/menus/routes",
      method: "get",
    });*/
  }

  /**
   * 获取菜单树形列表
   *
   * @param queryParams
   */
  static getList(queryParams: MenuQuery) {
    return request<any, MenuVO[]>({
      url: "/api/v1/menus",
      method: "get",
      params: queryParams,
    });
  }

  /**
   * 获取菜单下拉数据源
   */
  static getOptions() {
    return request<any, OptionType[]>({
      url: "/api/v1/menus/options",
      method: "get",
    });
  }

  /**
   * 获取菜单表单数据
   *
   * @param id
   */
  static getFormData(id: number) {
    return request<any, MenuForm>({
      url: "/api/v1/menus/" + id + "/form",
      method: "get",
    });
  }

  /**
   * 添加菜单
   *
   * @param data
   */
  static add(data: MenuForm) {
    return request({
      url: "/api/v1/menus",
      method: "post",
      data: data,
    });
  }

  /**
   * 修改菜单
   *
   * @param id
   * @param data
   */
  static update(id: string, data: MenuForm) {
    return request({
      url: "/api/v1/menus/" + id,
      method: "put",
      data: data,
    });
  }

  /**
   * 删除菜单
   *
   * @param id 菜单ID
   */
  static deleteById(id: number) {
    return request({
      url: "/api/v1/menus/" + id,
      method: "delete",
    });
  }
}

export default MenuAPI;
